# Gramophone Tools
Collection of tools to be used with the Gramophone system by Femtonics Ltd. 

# Installation
To install run the following command in the terminal:

``` pip install GramophoneTools ```

# Updating
To find out if there is a newer version available run:

``` pip list -o ```

If GramohoneTools shows up in the list you can update it by running:

``` pip install -U GramophoneTools ```

# Usage
The user guide for Gramophone systems can be found here: [ADD LINK]

## Gramophone recorder
To start the velocity recorder run the ``` gramrec ``` command. In windows you can press the Win+R keyboard shortcut to display the 'Run' window and type it in there.

## LinMaze
Make a .py file that describes the conditioning task and run it with python.exe.